" Vim filetype plugin
" Language:	dnsmasq
" Maintainer:	dringsim <dringsim@qq.com>
" Last Change:	2025-02-18

if exists('b:did_ftplugin')
  finish
endif

" Behaves mostly just like cfg
runtime! ftplugin/cfg.vim
