" Name:         Catppuccin Latte (for light) and Mocha (for dark)
" Description:  Soothing pastel theme for the high-spirited!
" Author:       The Catppuccin Community <catppuccin.com>
" Maintainer:   Mao-Yining <mao.yining@outlook.com>
" URL:          https://github.com/vim/colorschemes
" Last Change:  2026 May 04

" Generated by Colortemplate v3.0.0-rc1

hi clear
let g:colors_name = 'catppuccin'

let s:t_Co = has('gui_running') ? 16777216 : str2nr(&t_Co)
let s:tgc = has('termguicolors') && &termguicolors

hi! link Boolean Constant
hi! link CursorLineFold FoldColumn
hi! link CursorLineSign SignColumn
hi! link Debug Special
hi! link Define PreProc
hi! link Float Constant
hi! link Ignore Comment
hi! link IncSearch CurSearch
hi! link LineNrAbove LineNr
hi! link LineNrBelow LineNr
hi! link Number Constant
hi! link PopupNotification WarningMsg
hi! link PreCondit PreProc
hi! link SpecialChar Special
hi! link SpecialComment Special
hi! link SpecialKey NonText
hi! link StatusLineTerm StatusLine
hi! link StatusLineTermNC StatusLineNC
hi! link Terminal Normal
hi! link Typedef Type

if &background == 'dark'
  hi Normal guifg=#cdd6f4 guibg=#1e1e2e guisp=NONE gui=NONE ctermfg=189 ctermbg=233 cterm=NONE term=NONE
  hi Added guifg=#a6e3a1 guibg=NONE guisp=NONE gui=NONE ctermfg=114 ctermbg=NONE cterm=NONE term=NONE
  hi Bold guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
  hi Changed guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi Character guifg=#94e2d5 guibg=NONE guisp=NONE gui=NONE ctermfg=158 ctermbg=NONE cterm=NONE term=NONE
  hi ColorColumn guifg=NONE guibg=#181825 guisp=NONE gui=NONE ctermfg=NONE ctermbg=232 cterm=NONE term=reverse
  hi Comment guifg=#9399b2 guibg=NONE guisp=NONE gui=NONE ctermfg=103 ctermbg=NONE cterm=NONE term=bold
  hi Conceal guifg=#7f849c guibg=NONE guisp=NONE gui=NONE ctermfg=102 ctermbg=NONE cterm=NONE term=NONE
  hi Conditional guifg=#cba6f7 guibg=NONE guisp=NONE gui=NONE ctermfg=183 ctermbg=NONE cterm=NONE term=NONE
  hi Constant guifg=#fab387 guibg=NONE guisp=NONE gui=NONE ctermfg=216 ctermbg=NONE cterm=NONE term=NONE
  hi CurSearch guifg=#cdd6f4 guibg=#89556b guisp=NONE gui=NONE ctermfg=189 ctermbg=126 cterm=NONE term=reverse
  hi Cursor guifg=#1e1e2e guibg=#f5e0dc guisp=NONE gui=NONE ctermfg=233 ctermbg=224 cterm=NONE term=reverse
  hi CursorColumn guifg=NONE guibg=#181825 guisp=NONE gui=NONE ctermfg=NONE ctermbg=232 cterm=NONE term=NONE
  hi CursorIM guifg=#1e1e2e guibg=#cba6f7 guisp=NONE gui=NONE ctermfg=233 ctermbg=183 cterm=NONE term=NONE
  hi CursorLine guifg=NONE guibg=#2a2b3c guisp=NONE gui=NONE ctermfg=NONE ctermbg=236 cterm=NONE term=underline
  hi CursorLineNr guifg=#b4befe guibg=NONE guisp=NONE gui=NONE ctermfg=147 ctermbg=NONE cterm=NONE term=bold
  hi Delimiter guifg=#9399b2 guibg=NONE guisp=NONE gui=NONE ctermfg=103 ctermbg=NONE cterm=NONE term=NONE
  hi DiffAdd guifg=NONE guibg=#364143 guisp=NONE gui=NONE ctermfg=NONE ctermbg=22 cterm=NONE term=reverse
  hi DiffChange guifg=NONE guibg=#25293c guisp=NONE gui=NONE ctermfg=NONE ctermbg=235 cterm=NONE term=NONE
  hi DiffDelete guifg=NONE guibg=#443244 guisp=NONE gui=NONE ctermfg=NONE ctermbg=52 cterm=NONE term=reverse
  hi DiffText guifg=NONE guibg=#3e4b6b guisp=NONE gui=NONE ctermfg=NONE ctermbg=23 cterm=NONE term=reverse
  hi Directory guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi EndOfBuffer guifg=#45475a guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=NONE
  hi Error guifg=#f38ba8 guibg=NONE guisp=NONE gui=NONE ctermfg=211 ctermbg=NONE cterm=NONE term=bold,reverse
  hi ErrorMsg guifg=#f38ba8 guibg=NONE guisp=NONE gui=bold ctermfg=211 ctermbg=NONE cterm=bold term=bold,reverse
  hi Exception guifg=#cba6f7 guibg=NONE guisp=NONE gui=NONE ctermfg=183 ctermbg=NONE cterm=NONE term=NONE
  hi FoldColumn guifg=#6c7086 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=NONE
  hi Folded guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi Function guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi Identifier guifg=#f2cdcd guibg=NONE guisp=NONE gui=NONE ctermfg=181 ctermbg=NONE cterm=NONE term=NONE
  hi Include guifg=#cba6f7 guibg=NONE guisp=NONE gui=NONE ctermfg=183 ctermbg=NONE cterm=NONE term=NONE
  hi Italic guifg=NONE guibg=NONE guisp=NONE gui=italic ctermfg=NONE ctermbg=NONE cterm=italic term=italic
  hi Keyword guifg=#cba6f7 guibg=NONE guisp=NONE gui=NONE ctermfg=183 ctermbg=NONE cterm=NONE term=NONE
  hi Label guifg=#74c7ec guibg=NONE guisp=NONE gui=NONE ctermfg=117 ctermbg=NONE cterm=NONE term=NONE
  hi LineNr guifg=#45475a guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=NONE
  hi Macro guifg=#cba6f7 guibg=NONE guisp=NONE gui=NONE ctermfg=183 ctermbg=NONE cterm=NONE term=NONE
  hi MatchParen guifg=#fab387 guibg=NONE guisp=NONE gui=bold ctermfg=216 ctermbg=NONE cterm=bold term=bold,underline
  hi ModeMsg guifg=#cdd6f4 guibg=NONE guisp=NONE gui=bold ctermfg=189 ctermbg=NONE cterm=bold term=bold
  hi MoreMsg guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi NonText guifg=#6c7086 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=NONE
  hi Operator guifg=#89dceb guibg=NONE guisp=NONE gui=NONE ctermfg=116 ctermbg=NONE cterm=NONE term=NONE
  hi Pmenu guifg=#9399b2 guibg=#181825 guisp=NONE gui=NONE ctermfg=103 ctermbg=232 cterm=NONE term=reverse
  hi PmenuExtra guifg=#6c7086 guibg=#181825 guisp=NONE gui=NONE ctermfg=59 ctermbg=232 cterm=NONE term=NONE
  hi PmenuExtraSel guifg=#6c7086 guibg=#313244 guisp=NONE gui=bold ctermfg=59 ctermbg=236 cterm=bold term=bold
  hi PmenuMatch guifg=#cdd6f4 guibg=NONE guisp=NONE gui=bold ctermfg=189 ctermbg=NONE cterm=bold term=bold
  hi PmenuMatchSel guifg=#cdd6f4 guibg=NONE guisp=NONE gui=bold ctermfg=189 ctermbg=NONE cterm=bold term=bold
  hi PmenuSbar guifg=NONE guibg=#313244 guisp=NONE gui=NONE ctermfg=NONE ctermbg=236 cterm=NONE term=reverse
  hi PmenuSel guifg=NONE guibg=#313244 guisp=NONE gui=bold ctermfg=NONE ctermbg=236 cterm=bold term=bold
  hi PmenuThumb guifg=NONE guibg=#6c7086 guisp=NONE gui=NONE ctermfg=NONE ctermbg=59 cterm=NONE term=NONE
  hi PreInsert guifg=#9399b2 guibg=NONE guisp=NONE gui=NONE ctermfg=103 ctermbg=NONE cterm=NONE term=NONE
  hi PreProc guifg=#f5c2e7 guibg=NONE guisp=NONE gui=NONE ctermfg=225 ctermbg=NONE cterm=NONE term=NONE
  hi Question guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=standout
  hi QuickFixLine guifg=NONE guibg=#52476a guisp=NONE gui=bold ctermfg=189 ctermbg=60 cterm=bold term=NONE
  hi Removed guifg=#f38ba8 guibg=NONE guisp=NONE gui=NONE ctermfg=211 ctermbg=NONE cterm=NONE term=NONE
  hi Repeat guifg=#cba6f7 guibg=NONE guisp=NONE gui=NONE ctermfg=183 ctermbg=NONE cterm=NONE term=NONE
  hi Search guifg=#cdd6f4 guibg=#3e5767 guisp=NONE gui=NONE ctermfg=189 ctermbg=24 cterm=NONE term=reverse
  hi SignColumn guifg=#45475a guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=reverse
  hi Special guifg=#f5c2e7 guibg=NONE guisp=NONE gui=NONE ctermfg=225 ctermbg=NONE cterm=NONE term=NONE
  hi SpellBad guifg=NONE guibg=NONE guisp=#f38ba8 gui=undercurl ctermfg=211 ctermbg=NONE cterm=underline term=underline
  hi SpellCap guifg=NONE guibg=NONE guisp=#f9e2af gui=undercurl ctermfg=222 ctermbg=NONE cterm=underline term=underline
  hi SpellLocal guifg=NONE guibg=NONE guisp=#89b4fa gui=undercurl ctermfg=111 ctermbg=NONE cterm=underline term=underline
  hi SpellRare guifg=NONE guibg=NONE guisp=#a6e3a1 gui=undercurl ctermfg=114 ctermbg=NONE cterm=underline term=underline
  hi Statement guifg=#cba6f7 guibg=NONE guisp=NONE gui=NONE ctermfg=183 ctermbg=NONE cterm=NONE term=NONE
  hi StatusLine guifg=#cdd6f4 guibg=#11111b guisp=NONE gui=bold ctermfg=189 ctermbg=16 cterm=bold term=bold,reverse
  hi StatusLineNC guifg=#6c7086 guibg=#181825 guisp=NONE gui=NONE ctermfg=59 ctermbg=232 cterm=NONE term=bold,underline
  hi StorageClass guifg=#f9e2af guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE
  hi String guifg=#a6e3a1 guibg=NONE guisp=NONE gui=NONE ctermfg=114 ctermbg=NONE cterm=NONE term=NONE
  hi Structure guifg=#f9e2af guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE
  hi TabLine guifg=#6c7086 guibg=#11111b guisp=NONE gui=NONE ctermfg=59 ctermbg=16 cterm=NONE term=bold,underline
  hi TabLineFill guifg=NONE guibg=#181825 guisp=NONE gui=NONE ctermfg=NONE ctermbg=232 cterm=NONE term=NONE
  hi TabLineSel guifg=#cdd6f4 guibg=#1e1e2e guisp=NONE gui=NONE ctermfg=189 ctermbg=233 cterm=NONE term=bold,reverse
  hi Tag guifg=#b4befe guibg=NONE guisp=NONE gui=bold ctermfg=147 ctermbg=NONE cterm=bold term=bold
  hi Title guifg=#89b4fa guibg=NONE guisp=NONE gui=bold ctermfg=111 ctermbg=NONE cterm=bold term=NONE
  hi TitleBar guifg=#cdd6f4 guibg=#181825 guisp=NONE gui=NONE ctermfg=189 ctermbg=232 cterm=NONE term=NONE
  hi TitleBarNC guifg=#6c7086 guibg=#11111b guisp=NONE gui=NONE ctermfg=59 ctermbg=16 cterm=NONE term=NONE
  hi Todo guifg=#f2cdcd guibg=NONE guisp=NONE gui=bold ctermfg=181 ctermbg=NONE cterm=bold term=bold,reverse
  hi ToolbarButton guifg=#f5e0dc guibg=NONE guisp=NONE gui=NONE ctermfg=224 ctermbg=NONE cterm=NONE term=bold,reverse
  hi ToolbarLine guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
  hi Type guifg=#f9e2af guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE
  hi Underlined guifg=NONE guibg=NONE guisp=NONE gui=underline ctermfg=NONE ctermbg=NONE cterm=underline term=underline
  hi VertSplit guifg=#11111b guibg=NONE guisp=NONE gui=NONE ctermfg=16 ctermbg=NONE cterm=NONE term=NONE
  hi Visual guifg=NONE guibg=#45475a guisp=NONE gui=NONE ctermfg=240 ctermbg=189 cterm=reverse term=reverse
  hi VisualNOS guifg=NONE guibg=#45475a guisp=NONE gui=bold ctermfg=NONE ctermbg=240 cterm=bold term=NONE
  hi WarningMsg guifg=#f9e2af guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=standout
  hi WildMenu guifg=NONE guibg=#6c7086 guisp=NONE gui=NONE ctermfg=NONE ctermbg=59 cterm=NONE term=bold
  hi csvCol0 guifg=#f38ba8 guibg=NONE guisp=NONE gui=NONE ctermfg=211 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol1 guifg=#fab387 guibg=NONE guisp=NONE gui=NONE ctermfg=216 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol2 guifg=#f9e2af guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol3 guifg=#a6e3a1 guibg=NONE guisp=NONE gui=NONE ctermfg=114 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol4 guifg=#89dceb guibg=NONE guisp=NONE gui=NONE ctermfg=116 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol5 guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol6 guifg=#b4befe guibg=NONE guisp=NONE gui=NONE ctermfg=147 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol7 guifg=#cba6f7 guibg=NONE guisp=NONE gui=NONE ctermfg=183 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol8 guifg=#f5c2e7 guibg=NONE guisp=NONE gui=NONE ctermfg=225 ctermbg=NONE cterm=NONE term=NONE
  hi debugBreakpoint guifg=#6c7086 guibg=#1e1e2e guisp=NONE gui=NONE ctermfg=59 ctermbg=233 cterm=NONE term=NONE
  hi debugPC guifg=NONE guibg=#11111b guisp=NONE gui=NONE ctermfg=NONE ctermbg=16 cterm=NONE term=NONE
  hi diffAdded guifg=#a6e3a1 guibg=NONE guisp=NONE gui=NONE ctermfg=114 ctermbg=NONE cterm=NONE term=NONE
  hi diffChanged guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi diffFile guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi diffIndexLine guifg=#94e2d5 guibg=NONE guisp=NONE gui=NONE ctermfg=158 ctermbg=NONE cterm=NONE term=NONE
  hi diffLine guifg=#6c7086 guibg=NONE guisp=NONE gui=NONE ctermfg=59 ctermbg=NONE cterm=NONE term=NONE
  hi diffNewFile guifg=#fab387 guibg=NONE guisp=NONE gui=NONE ctermfg=216 ctermbg=NONE cterm=NONE term=NONE
  hi diffOldFile guifg=#f9e2af guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE
  hi diffRemoved guifg=#f38ba8 guibg=NONE guisp=NONE gui=NONE ctermfg=211 ctermbg=NONE cterm=NONE term=NONE
  hi lCursor guifg=#1e1e2e guibg=#f38ba8 guisp=NONE gui=NONE ctermfg=233 ctermbg=211 cterm=NONE term=NONE
  hi markdownCode guifg=#f2cdcd guibg=NONE guisp=NONE gui=NONE ctermfg=181 ctermbg=NONE cterm=NONE term=NONE
  hi markdownCodeBlock guifg=#f2cdcd guibg=NONE guisp=NONE gui=NONE ctermfg=181 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH1 guifg=#f38ba8 guibg=NONE guisp=NONE gui=NONE ctermfg=211 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH2 guifg=#fab387 guibg=NONE guisp=NONE gui=NONE ctermfg=216 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH3 guifg=#f9e2af guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH4 guifg=#a6e3a1 guibg=NONE guisp=NONE gui=NONE ctermfg=114 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH5 guifg=#74c7ec guibg=NONE guisp=NONE gui=NONE ctermfg=117 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH6 guifg=#b4befe guibg=NONE guisp=NONE gui=NONE ctermfg=147 ctermbg=NONE cterm=NONE term=NONE
  hi markdownHeadingDelimiter guifg=#fab387 guibg=NONE guisp=NONE gui=bold ctermfg=216 ctermbg=NONE cterm=bold term=bold
  hi markdownLinkText guifg=#89b4fa guibg=NONE guisp=NONE gui=underline ctermfg=111 ctermbg=NONE cterm=underline term=underline
  hi qfFileName guifg=#89b4fa guibg=NONE guisp=NONE gui=NONE ctermfg=111 ctermbg=NONE cterm=NONE term=NONE
  hi qfLineNr guifg=#f9e2af guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE

  if s:tgc || s:t_Co >= 256
    if s:tgc
      hi QuickFixLine cterm=NONE
      hi Visual cterm=NONE
    endif
    finish
  endif

  if s:t_Co >= 16
    hi Normal ctermfg=White ctermbg=Black cterm=NONE
    hi Added ctermfg=Green ctermbg=NONE cterm=NONE
    hi Bold ctermfg=NONE ctermbg=NONE cterm=bold
    hi Changed ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Character ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi Comment ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Conditional ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Constant ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi CurSearch ctermfg=White ctermbg=Red cterm=NONE
    hi Cursor ctermfg=Black ctermbg=Yellow cterm=NONE
    hi CursorColumn ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi CursorIM ctermfg=Black ctermbg=DarkMagenta cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=White ctermbg=NONE cterm=NONE
    hi Delimiter ctermfg=Grey ctermbg=NONE cterm=NONE
    hi DiffAdd ctermfg=Black ctermbg=DarkGreen cterm=NONE
    hi DiffChange ctermfg=Black ctermbg=DarkYellow cterm=NONE
    hi DiffDelete ctermfg=Black ctermbg=DarkRed cterm=NONE
    hi DiffText ctermfg=Black ctermbg=DarkCyan cterm=NONE
    hi Directory ctermfg=Blue ctermbg=NONE cterm=NONE
    hi EndOfBuffer ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Error ctermfg=Red ctermbg=NONE cterm=NONE
    hi ErrorMsg ctermfg=Red ctermbg=NONE cterm=bold
    hi Exception ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi FoldColumn ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Folded ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Function ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Identifier ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Include ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Italic ctermfg=NONE ctermbg=NONE cterm=italic
    hi Keyword ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Label ctermfg=DarkCyan ctermbg=NONE cterm=NONE
    hi LineNr ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Macro ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=DarkYellow ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=White ctermbg=NONE cterm=bold
    hi MoreMsg ctermfg=Blue ctermbg=NONE cterm=NONE
    hi NonText ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Operator ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=Grey ctermbg=DarkGrey cterm=NONE
    hi PmenuExtra ctermfg=Grey ctermbg=DarkGrey cterm=NONE
    hi PmenuExtraSel ctermfg=Grey ctermbg=DarkYellow cterm=bold
    hi PmenuMatch ctermfg=White ctermbg=NONE cterm=bold
    hi PmenuMatchSel ctermfg=White ctermbg=NONE cterm=bold
    hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuSel ctermfg=NONE ctermbg=DarkYellow cterm=bold
    hi PmenuThumb ctermfg=NONE ctermbg=Grey cterm=NONE
    hi PreInsert ctermfg=Grey ctermbg=NONE cterm=NONE
    hi PreProc ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi Question ctermfg=Blue ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=Black ctermbg=Magenta cterm=bold
    hi Removed ctermfg=Red ctermbg=NONE cterm=NONE
    hi Repeat ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Search ctermfg=White ctermbg=DarkBlue cterm=NONE
    hi SignColumn ctermfg=Black ctermbg=NONE cterm=NONE
    hi Special ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=Red ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=Yellow ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=Blue ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=Green ctermbg=NONE cterm=underline
    hi Statement ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi StatusLine ctermfg=White ctermbg=DarkGrey cterm=bold,reverse
    hi StatusLineNC ctermfg=Grey ctermbg=DarkGrey cterm=NONE
    hi StorageClass ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi String ctermfg=Green ctermbg=NONE cterm=NONE
    hi Structure ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi TabLine ctermfg=Grey ctermbg=Black cterm=NONE
    hi TabLineFill ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi TabLineSel ctermfg=White ctermbg=Black cterm=NONE
    hi Tag ctermfg=LightGrey ctermbg=NONE cterm=bold
    hi Title ctermfg=Blue ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=White ctermbg=DarkGrey cterm=NONE
    hi TitleBarNC ctermfg=Grey ctermbg=Black cterm=NONE
    hi Todo ctermfg=Yellow ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Type ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplit ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Visual ctermfg=Blue ctermbg=Black cterm=bold,reverse
    hi VisualNOS ctermfg=NONE ctermbg=Black cterm=bold
    hi WarningMsg ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi WildMenu ctermfg=NONE ctermbg=Grey cterm=NONE
    hi csvCol0 ctermfg=Red ctermbg=NONE cterm=NONE
    hi csvCol1 ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi csvCol2 ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi csvCol3 ctermfg=Green ctermbg=NONE cterm=NONE
    hi csvCol4 ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi csvCol5 ctermfg=Blue ctermbg=NONE cterm=NONE
    hi csvCol6 ctermfg=LightGrey ctermbg=NONE cterm=NONE
    hi csvCol7 ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi csvCol8 ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi debugBreakpoint ctermfg=Grey ctermbg=Black cterm=NONE
    hi debugPC ctermfg=NONE ctermbg=Black cterm=NONE
    hi diffAdded ctermfg=Green ctermbg=NONE cterm=NONE
    hi diffChanged ctermfg=Blue ctermbg=NONE cterm=NONE
    hi diffFile ctermfg=Blue ctermbg=NONE cterm=NONE
    hi diffIndexLine ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi diffLine ctermfg=Grey ctermbg=NONE cterm=NONE
    hi diffNewFile ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi diffOldFile ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi diffRemoved ctermfg=Red ctermbg=NONE cterm=NONE
    hi lCursor ctermfg=Black ctermbg=Red cterm=NONE
    hi markdownCode ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi markdownCodeBlock ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi markdownH1 ctermfg=Red ctermbg=NONE cterm=NONE
    hi markdownH2 ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi markdownH3 ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi markdownH4 ctermfg=Green ctermbg=NONE cterm=NONE
    hi markdownH5 ctermfg=DarkCyan ctermbg=NONE cterm=NONE
    hi markdownH6 ctermfg=LightGrey ctermbg=NONE cterm=NONE
    hi markdownHeadingDelimiter ctermfg=DarkYellow ctermbg=NONE cterm=bold
    hi markdownLinkText ctermfg=Blue ctermbg=NONE cterm=underline
    hi qfFileName ctermfg=Blue ctermbg=NONE cterm=NONE
    hi qfLineNr ctermfg=Yellow ctermbg=NONE cterm=NONE
    finish
  endif

  if s:t_Co >= 8
    hi Normal ctermfg=White ctermbg=Black cterm=NONE
    hi Added ctermfg=Green ctermbg=NONE cterm=NONE
    hi Bold ctermfg=NONE ctermbg=NONE cterm=bold
    hi Changed ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Character ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=Black ctermbg=Grey cterm=NONE
    hi Comment ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Conditional ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Constant ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi CurSearch ctermfg=White ctermbg=Red cterm=NONE
    hi Cursor ctermfg=Black ctermbg=Yellow cterm=NONE
    hi CursorColumn ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi CursorIM ctermfg=Black ctermbg=DarkMagenta cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=White ctermbg=NONE cterm=NONE
    hi Delimiter ctermfg=Grey ctermbg=NONE cterm=NONE
    hi DiffAdd ctermfg=Black ctermbg=DarkGreen cterm=NONE
    hi DiffChange ctermfg=Black ctermbg=DarkYellow cterm=NONE
    hi DiffDelete ctermfg=Black ctermbg=DarkRed cterm=NONE
    hi DiffText ctermfg=Black ctermbg=DarkCyan cterm=NONE
    hi Directory ctermfg=Blue ctermbg=NONE cterm=NONE
    hi EndOfBuffer ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Error ctermfg=Red ctermbg=NONE cterm=NONE
    hi ErrorMsg ctermfg=Red ctermbg=NONE cterm=bold
    hi Exception ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi FoldColumn ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Folded ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Function ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Identifier ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Include ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Italic ctermfg=NONE ctermbg=NONE cterm=italic
    hi Keyword ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Label ctermfg=DarkCyan ctermbg=NONE cterm=NONE
    hi LineNr ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Macro ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=DarkYellow ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=White ctermbg=NONE cterm=bold
    hi MoreMsg ctermfg=Blue ctermbg=NONE cterm=NONE
    hi NonText ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Operator ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=Grey ctermbg=DarkGrey cterm=NONE
    hi PmenuExtra ctermfg=Grey ctermbg=DarkGrey cterm=NONE
    hi PmenuExtraSel ctermfg=Grey ctermbg=DarkYellow cterm=bold
    hi PmenuMatch ctermfg=White ctermbg=NONE cterm=bold
    hi PmenuMatchSel ctermfg=White ctermbg=NONE cterm=bold
    hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuSel ctermfg=NONE ctermbg=DarkYellow cterm=bold
    hi PmenuThumb ctermfg=NONE ctermbg=Grey cterm=NONE
    hi PreInsert ctermfg=Grey ctermbg=NONE cterm=NONE
    hi PreProc ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi Question ctermfg=Blue ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=White ctermbg=Magenta cterm=bold
    hi Removed ctermfg=Red ctermbg=NONE cterm=NONE
    hi Repeat ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Search ctermfg=White ctermbg=DarkBlue cterm=NONE
    hi SignColumn ctermfg=Black ctermbg=NONE cterm=NONE
    hi Special ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=Red ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=Yellow ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=Blue ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=Green ctermbg=NONE cterm=underline
    hi Statement ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi StatusLine ctermfg=White ctermbg=DarkGrey cterm=bold,reverse
    hi StatusLineNC ctermfg=Grey ctermbg=DarkGrey cterm=reverse
    hi StorageClass ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi String ctermfg=Green ctermbg=NONE cterm=NONE
    hi Structure ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi TabLine ctermfg=Grey ctermbg=Black cterm=NONE
    hi TabLineFill ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi TabLineSel ctermfg=White ctermbg=DarkGrey cterm=bold
    hi Tag ctermfg=LightGrey ctermbg=NONE cterm=bold
    hi Title ctermfg=Blue ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=White ctermbg=DarkGrey cterm=NONE
    hi TitleBarNC ctermfg=Grey ctermbg=Black cterm=NONE
    hi Todo ctermfg=Yellow ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Type ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplit ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Visual ctermfg=Blue ctermbg=Black cterm=bold,reverse
    hi VisualNOS ctermfg=NONE ctermbg=Black cterm=bold
    hi WarningMsg ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi WildMenu ctermfg=NONE ctermbg=Grey cterm=NONE
    hi csvCol0 ctermfg=Red ctermbg=NONE cterm=NONE
    hi csvCol1 ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi csvCol2 ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi csvCol3 ctermfg=Green ctermbg=NONE cterm=NONE
    hi csvCol4 ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi csvCol5 ctermfg=Blue ctermbg=NONE cterm=NONE
    hi csvCol6 ctermfg=LightGrey ctermbg=NONE cterm=NONE
    hi csvCol7 ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi csvCol8 ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi debugBreakpoint ctermfg=Grey ctermbg=Black cterm=NONE
    hi debugPC ctermfg=NONE ctermbg=Black cterm=NONE
    hi diffAdded ctermfg=Green ctermbg=NONE cterm=NONE
    hi diffChanged ctermfg=Blue ctermbg=NONE cterm=NONE
    hi diffFile ctermfg=Blue ctermbg=NONE cterm=NONE
    hi diffIndexLine ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi diffLine ctermfg=Grey ctermbg=NONE cterm=NONE
    hi diffNewFile ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi diffOldFile ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi diffRemoved ctermfg=Red ctermbg=NONE cterm=NONE
    hi lCursor ctermfg=Black ctermbg=Red cterm=NONE
    hi markdownCode ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi markdownCodeBlock ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi markdownH1 ctermfg=Red ctermbg=NONE cterm=NONE
    hi markdownH2 ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi markdownH3 ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi markdownH4 ctermfg=Green ctermbg=NONE cterm=NONE
    hi markdownH5 ctermfg=DarkCyan ctermbg=NONE cterm=NONE
    hi markdownH6 ctermfg=LightGrey ctermbg=NONE cterm=NONE
    hi markdownHeadingDelimiter ctermfg=DarkYellow ctermbg=NONE cterm=bold
    hi markdownLinkText ctermfg=Blue ctermbg=NONE cterm=underline
    hi qfFileName ctermfg=Blue ctermbg=NONE cterm=NONE
    hi qfLineNr ctermfg=Yellow ctermbg=NONE cterm=NONE
    finish
  endif

  if s:t_Co >= 0
    hi CursorLineFold term=underline
    hi CursorLineSign term=underline
    hi Float term=NONE
    hi Ignore term=NONE
    hi IncSearch term=bold,reverse,underline
    hi Number term=NONE
    hi SpecialKey term=bold
    hi StatusLineTerm term=bold,reverse
    hi StatusLineTermNC term=bold,underline
    hi Terminal term=NONE
    finish
  endif

  finish
endif

if &background == 'light'
  hi Normal guifg=#4c4f69 guibg=#eff1f5 guisp=NONE gui=NONE ctermfg=236 ctermbg=231 cterm=NONE term=NONE
  hi Added guifg=#40a02b guibg=NONE guisp=NONE gui=NONE ctermfg=34 ctermbg=NONE cterm=NONE term=NONE
  hi Bold guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold
  hi Changed guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi Character guifg=#179299 guibg=NONE guisp=NONE gui=NONE ctermfg=30 ctermbg=NONE cterm=NONE term=NONE
  hi ColorColumn guifg=NONE guibg=#e6e9ef guisp=NONE gui=NONE ctermfg=NONE ctermbg=255 cterm=NONE term=reverse
  hi Comment guifg=#7c7f93 guibg=NONE guisp=NONE gui=NONE ctermfg=103 ctermbg=NONE cterm=NONE term=bold
  hi Conceal guifg=#8c8fa1 guibg=NONE guisp=NONE gui=NONE ctermfg=246 ctermbg=NONE cterm=NONE term=NONE
  hi Conditional guifg=#8839ef guibg=NONE guisp=NONE gui=NONE ctermfg=93 ctermbg=NONE cterm=NONE term=NONE
  hi Constant guifg=#fe640b guibg=NONE guisp=NONE gui=NONE ctermfg=202 ctermbg=NONE cterm=NONE term=NONE
  hi CurSearch guifg=#4c4f69 guibg=#fc8fc3 guisp=NONE gui=NONE ctermfg=236 ctermbg=211 cterm=NONE term=reverse
  hi Cursor guifg=#eff1f5 guibg=#dc8a78 guisp=NONE gui=NONE ctermfg=231 ctermbg=174 cterm=NONE term=reverse
  hi CursorColumn guifg=NONE guibg=#e6e9ef guisp=NONE gui=NONE ctermfg=NONE ctermbg=255 cterm=NONE term=NONE
  hi CursorIM guifg=#eff1f5 guibg=#8839ef guisp=NONE gui=NONE ctermfg=231 ctermbg=93 cterm=NONE term=NONE
  hi CursorLine guifg=NONE guibg=#e9ebf1 guisp=NONE gui=NONE ctermfg=NONE ctermbg=253 cterm=NONE term=underline
  hi CursorLineNr guifg=#7287fd guibg=NONE guisp=NONE gui=NONE ctermfg=69 ctermbg=NONE cterm=NONE term=bold
  hi Delimiter guifg=#7c7f93 guibg=NONE guisp=NONE gui=NONE ctermfg=103 ctermbg=NONE cterm=NONE term=NONE
  hi DiffAdd guifg=NONE guibg=#d0e2d1 guisp=NONE gui=NONE ctermfg=NONE ctermbg=152 cterm=NONE term=reverse
  hi DiffChange guifg=NONE guibg=#e0e7f5 guisp=NONE gui=NONE ctermfg=NONE ctermbg=254 cterm=NONE term=NONE
  hi DiffDelete guifg=NONE guibg=#eac8d3 guisp=NONE gui=NONE ctermfg=NONE ctermbg=224 cterm=NONE term=reverse
  hi DiffText guifg=NONE guibg=#b0c7f5 guisp=NONE gui=NONE ctermfg=NONE ctermbg=153 cterm=NONE term=reverse
  hi Directory guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi EndOfBuffer guifg=#bcc0cc guibg=NONE guisp=NONE gui=NONE ctermfg=250 ctermbg=NONE cterm=NONE term=NONE
  hi Error guifg=#d20f39 guibg=NONE guisp=NONE gui=NONE ctermfg=161 ctermbg=NONE cterm=NONE term=bold,reverse
  hi ErrorMsg guifg=#d20f39 guibg=NONE guisp=NONE gui=bold ctermfg=161 ctermbg=NONE cterm=bold term=bold,reverse
  hi Exception guifg=#8839ef guibg=NONE guisp=NONE gui=NONE ctermfg=93 ctermbg=NONE cterm=NONE term=NONE
  hi FoldColumn guifg=#9ca0b0 guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=NONE
  hi Folded guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi Function guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi Identifier guifg=#dd7878 guibg=NONE guisp=NONE gui=NONE ctermfg=167 ctermbg=NONE cterm=NONE term=NONE
  hi Include guifg=#8839ef guibg=NONE guisp=NONE gui=NONE ctermfg=93 ctermbg=NONE cterm=NONE term=NONE
  hi Italic guifg=NONE guibg=NONE guisp=NONE gui=italic ctermfg=NONE ctermbg=NONE cterm=italic term=italic
  hi Keyword guifg=#8839ef guibg=NONE guisp=NONE gui=NONE ctermfg=93 ctermbg=NONE cterm=NONE term=NONE
  hi Label guifg=#209fb5 guibg=NONE guisp=NONE gui=NONE ctermfg=38 ctermbg=NONE cterm=NONE term=NONE
  hi LineNr guifg=#bcc0cc guibg=NONE guisp=NONE gui=NONE ctermfg=250 ctermbg=NONE cterm=NONE term=NONE
  hi Macro guifg=#8839ef guibg=NONE guisp=NONE gui=NONE ctermfg=93 ctermbg=NONE cterm=NONE term=NONE
  hi MatchParen guifg=#fe640b guibg=NONE guisp=NONE gui=bold ctermfg=202 ctermbg=NONE cterm=bold term=bold,underline
  hi ModeMsg guifg=#4c4f69 guibg=NONE guisp=NONE gui=bold ctermfg=236 ctermbg=NONE cterm=bold term=bold
  hi MoreMsg guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi NonText guifg=#9ca0b0 guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=NONE
  hi Operator guifg=#04a5e5 guibg=NONE guisp=NONE gui=NONE ctermfg=39 ctermbg=NONE cterm=NONE term=NONE
  hi Pmenu guifg=#7c7f93 guibg=#e6e9ef guisp=NONE gui=NONE ctermfg=103 ctermbg=255 cterm=NONE term=reverse
  hi PmenuExtra guifg=#9ca0b0 guibg=#e6e9ef guisp=NONE gui=NONE ctermfg=247 ctermbg=255 cterm=NONE term=NONE
  hi PmenuExtraSel guifg=#9ca0b0 guibg=#ccd0da guisp=NONE gui=bold ctermfg=247 ctermbg=253 cterm=bold term=bold
  hi PmenuMatch guifg=#4c4f69 guibg=NONE guisp=NONE gui=bold ctermfg=236 ctermbg=NONE cterm=bold term=bold
  hi PmenuMatchSel guifg=#4c4f69 guibg=NONE guisp=NONE gui=bold ctermfg=236 ctermbg=NONE cterm=bold term=bold
  hi PmenuSbar guifg=NONE guibg=#ccd0da guisp=NONE gui=NONE ctermfg=NONE ctermbg=253 cterm=NONE term=reverse
  hi PmenuSel guifg=NONE guibg=#ccd0da guisp=NONE gui=bold ctermfg=NONE ctermbg=253 cterm=bold term=bold
  hi PmenuThumb guifg=NONE guibg=#9ca0b0 guisp=NONE gui=NONE ctermfg=NONE ctermbg=247 cterm=NONE term=NONE
  hi PreInsert guifg=#7c7f93 guibg=NONE guisp=NONE gui=NONE ctermfg=103 ctermbg=NONE cterm=NONE term=NONE
  hi PreProc guifg=#ea76cb guibg=NONE guisp=NONE gui=NONE ctermfg=206 ctermbg=NONE cterm=NONE term=NONE
  hi Question guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=standout
  hi QuickFixLine guifg=NONE guibg=#d0baf3 guisp=NONE gui=bold ctermfg=236 ctermbg=183 cterm=bold term=NONE
  hi Removed guifg=#d20f39 guibg=NONE guisp=NONE gui=NONE ctermfg=161 ctermbg=NONE cterm=NONE term=NONE
  hi Repeat guifg=#8839ef guibg=NONE guisp=NONE gui=NONE ctermfg=93 ctermbg=NONE cterm=NONE term=NONE
  hi Search guifg=#4c4f69 guibg=#a8daf0 guisp=NONE gui=NONE ctermfg=236 ctermbg=117 cterm=NONE term=reverse
  hi SignColumn guifg=#bcc0cc guibg=NONE guisp=NONE gui=NONE ctermfg=250 ctermbg=NONE cterm=NONE term=reverse
  hi Special guifg=#ea76cb guibg=NONE guisp=NONE gui=NONE ctermfg=206 ctermbg=NONE cterm=NONE term=NONE
  hi SpellBad guifg=NONE guibg=NONE guisp=#d20f39 gui=undercurl ctermfg=161 ctermbg=NONE cterm=underline term=underline
  hi SpellCap guifg=NONE guibg=NONE guisp=#df8e1d gui=undercurl ctermfg=172 ctermbg=NONE cterm=underline term=underline
  hi SpellLocal guifg=NONE guibg=NONE guisp=#1e66f5 gui=undercurl ctermfg=27 ctermbg=NONE cterm=underline term=underline
  hi SpellRare guifg=NONE guibg=NONE guisp=#40a02b gui=undercurl ctermfg=34 ctermbg=NONE cterm=underline term=underline
  hi Statement guifg=#8839ef guibg=NONE guisp=NONE gui=NONE ctermfg=93 ctermbg=NONE cterm=NONE term=NONE
  hi StatusLine guifg=#4c4f69 guibg=#dce0e8 guisp=NONE gui=bold ctermfg=236 ctermbg=254 cterm=bold term=bold,reverse
  hi StatusLineNC guifg=#9ca0b0 guibg=#e6e9ef guisp=NONE gui=NONE ctermfg=247 ctermbg=255 cterm=NONE term=bold,underline
  hi StorageClass guifg=#df8e1d guibg=NONE guisp=NONE gui=NONE ctermfg=172 ctermbg=NONE cterm=NONE term=NONE
  hi String guifg=#40a02b guibg=NONE guisp=NONE gui=NONE ctermfg=34 ctermbg=NONE cterm=NONE term=NONE
  hi Structure guifg=#df8e1d guibg=NONE guisp=NONE gui=NONE ctermfg=172 ctermbg=NONE cterm=NONE term=NONE
  hi TabLine guifg=#9ca0b0 guibg=#dce0e8 guisp=NONE gui=NONE ctermfg=247 ctermbg=254 cterm=NONE term=bold,underline
  hi TabLineFill guifg=NONE guibg=#e6e9ef guisp=NONE gui=NONE ctermfg=NONE ctermbg=255 cterm=NONE term=NONE
  hi TabLineSel guifg=#4c4f69 guibg=#eff1f5 guisp=NONE gui=NONE ctermfg=236 ctermbg=231 cterm=NONE term=bold,reverse
  hi Tag guifg=#7287fd guibg=NONE guisp=NONE gui=bold ctermfg=69 ctermbg=NONE cterm=bold term=bold
  hi Title guifg=#1e66f5 guibg=NONE guisp=NONE gui=bold ctermfg=27 ctermbg=NONE cterm=bold term=NONE
  hi TitleBar guifg=#4c4f69 guibg=#e6e9ef guisp=NONE gui=NONE ctermfg=236 ctermbg=255 cterm=NONE term=NONE
  hi TitleBarNC guifg=#9ca0b0 guibg=#dce0e8 guisp=NONE gui=NONE ctermfg=247 ctermbg=254 cterm=NONE term=NONE
  hi Todo guifg=#dd7878 guibg=NONE guisp=NONE gui=bold ctermfg=167 ctermbg=NONE cterm=bold term=bold,reverse
  hi ToolbarButton guifg=#dc8a78 guibg=NONE guisp=NONE gui=NONE ctermfg=174 ctermbg=NONE cterm=NONE term=bold,reverse
  hi ToolbarLine guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
  hi Type guifg=#df8e1d guibg=NONE guisp=NONE gui=NONE ctermfg=172 ctermbg=NONE cterm=NONE term=NONE
  hi Underlined guifg=NONE guibg=NONE guisp=NONE gui=underline ctermfg=NONE ctermbg=NONE cterm=underline term=underline
  hi VertSplit guifg=#dce0e8 guibg=NONE guisp=NONE gui=NONE ctermfg=254 ctermbg=NONE cterm=NONE term=NONE
  hi Visual guifg=NONE guibg=#bcc0cc guisp=NONE gui=NONE ctermfg=250 ctermbg=236 cterm=reverse term=reverse
  hi VisualNOS guifg=NONE guibg=#bcc0cc guisp=NONE gui=bold ctermfg=NONE ctermbg=250 cterm=bold term=NONE
  hi WarningMsg guifg=#df8e1d guibg=NONE guisp=NONE gui=NONE ctermfg=172 ctermbg=NONE cterm=NONE term=standout
  hi WildMenu guifg=NONE guibg=#9ca0b0 guisp=NONE gui=NONE ctermfg=NONE ctermbg=247 cterm=NONE term=bold
  hi csvCol0 guifg=#d20f39 guibg=NONE guisp=NONE gui=NONE ctermfg=161 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol1 guifg=#fe640b guibg=NONE guisp=NONE gui=NONE ctermfg=202 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol2 guifg=#df8e1d guibg=NONE guisp=NONE gui=NONE ctermfg=172 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol3 guifg=#40a02b guibg=NONE guisp=NONE gui=NONE ctermfg=34 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol4 guifg=#04a5e5 guibg=NONE guisp=NONE gui=NONE ctermfg=39 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol5 guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol6 guifg=#7287fd guibg=NONE guisp=NONE gui=NONE ctermfg=69 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol7 guifg=#8839ef guibg=NONE guisp=NONE gui=NONE ctermfg=93 ctermbg=NONE cterm=NONE term=NONE
  hi csvCol8 guifg=#ea76cb guibg=NONE guisp=NONE gui=NONE ctermfg=206 ctermbg=NONE cterm=NONE term=NONE
  hi debugBreakpoint guifg=#9ca0b0 guibg=#eff1f5 guisp=NONE gui=NONE ctermfg=247 ctermbg=231 cterm=NONE term=NONE
  hi debugPC guifg=NONE guibg=#dce0e8 guisp=NONE gui=NONE ctermfg=NONE ctermbg=254 cterm=NONE term=NONE
  hi diffAdded guifg=#40a02b guibg=NONE guisp=NONE gui=NONE ctermfg=34 ctermbg=NONE cterm=NONE term=NONE
  hi diffChanged guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi diffFile guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi diffIndexLine guifg=#179299 guibg=NONE guisp=NONE gui=NONE ctermfg=30 ctermbg=NONE cterm=NONE term=NONE
  hi diffLine guifg=#9ca0b0 guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=NONE
  hi diffNewFile guifg=#fe640b guibg=NONE guisp=NONE gui=NONE ctermfg=202 ctermbg=NONE cterm=NONE term=NONE
  hi diffOldFile guifg=#df8e1d guibg=NONE guisp=NONE gui=NONE ctermfg=172 ctermbg=NONE cterm=NONE term=NONE
  hi diffRemoved guifg=#d20f39 guibg=NONE guisp=NONE gui=NONE ctermfg=161 ctermbg=NONE cterm=NONE term=NONE
  hi lCursor guifg=#eff1f5 guibg=#d20f39 guisp=NONE gui=NONE ctermfg=231 ctermbg=161 cterm=NONE term=NONE
  hi markdownCode guifg=#dd7878 guibg=NONE guisp=NONE gui=NONE ctermfg=167 ctermbg=NONE cterm=NONE term=NONE
  hi markdownCodeBlock guifg=#dd7878 guibg=NONE guisp=NONE gui=NONE ctermfg=167 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH1 guifg=#d20f39 guibg=NONE guisp=NONE gui=NONE ctermfg=161 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH2 guifg=#fe640b guibg=NONE guisp=NONE gui=NONE ctermfg=202 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH3 guifg=#df8e1d guibg=NONE guisp=NONE gui=NONE ctermfg=172 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH4 guifg=#40a02b guibg=NONE guisp=NONE gui=NONE ctermfg=34 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH5 guifg=#209fb5 guibg=NONE guisp=NONE gui=NONE ctermfg=38 ctermbg=NONE cterm=NONE term=NONE
  hi markdownH6 guifg=#7287fd guibg=NONE guisp=NONE gui=NONE ctermfg=69 ctermbg=NONE cterm=NONE term=NONE
  hi markdownHeadingDelimiter guifg=#fe640b guibg=NONE guisp=NONE gui=bold ctermfg=202 ctermbg=NONE cterm=bold term=bold
  hi markdownLinkText guifg=#1e66f5 guibg=NONE guisp=NONE gui=underline ctermfg=27 ctermbg=NONE cterm=underline term=underline
  hi qfFileName guifg=#1e66f5 guibg=NONE guisp=NONE gui=NONE ctermfg=27 ctermbg=NONE cterm=NONE term=NONE
  hi qfLineNr guifg=#df8e1d guibg=NONE guisp=NONE gui=NONE ctermfg=172 ctermbg=NONE cterm=NONE term=NONE

  if s:tgc || s:t_Co >= 256
    if s:tgc
      hi QuickFixLine cterm=NONE
      hi Visual cterm=NONE
    endif
    finish
  endif

  if s:t_Co >= 16
    hi Normal ctermfg=Black ctermbg=White cterm=NONE
    hi Added ctermfg=Green ctermbg=NONE cterm=NONE
    hi Bold ctermfg=NONE ctermbg=NONE cterm=bold
    hi Changed ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Character ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=NONE ctermbg=Grey cterm=NONE
    hi Comment ctermfg=Black ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Conditional ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Constant ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi CurSearch ctermfg=Black ctermbg=Red cterm=NONE
    hi Cursor ctermfg=White ctermbg=Red cterm=NONE
    hi CursorColumn ctermfg=NONE ctermbg=Grey cterm=NONE
    hi CursorIM ctermfg=White ctermbg=DarkMagenta cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=Black ctermbg=NONE cterm=NONE
    hi Delimiter ctermfg=Black ctermbg=NONE cterm=NONE
    hi DiffAdd ctermfg=White ctermbg=Green cterm=NONE
    hi DiffChange ctermfg=White ctermbg=Yellow cterm=NONE
    hi DiffDelete ctermfg=White ctermbg=Red cterm=NONE
    hi DiffText ctermfg=White ctermbg=Cyan cterm=NONE
    hi Directory ctermfg=Blue ctermbg=NONE cterm=NONE
    hi EndOfBuffer ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Error ctermfg=Red ctermbg=NONE cterm=NONE
    hi ErrorMsg ctermfg=Red ctermbg=NONE cterm=bold
    hi Exception ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi FoldColumn ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Folded ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Function ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Identifier ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi Include ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Italic ctermfg=NONE ctermbg=NONE cterm=italic
    hi Keyword ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Label ctermfg=DarkCyan ctermbg=NONE cterm=NONE
    hi LineNr ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Macro ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=DarkYellow ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=Black ctermbg=NONE cterm=bold
    hi MoreMsg ctermfg=Blue ctermbg=NONE cterm=NONE
    hi NonText ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Operator ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=Black ctermbg=Grey cterm=NONE
    hi PmenuExtra ctermfg=DarkGrey ctermbg=Grey cterm=NONE
    hi PmenuExtraSel ctermfg=DarkGrey ctermbg=Grey cterm=bold
    hi PmenuMatch ctermfg=Black ctermbg=NONE cterm=bold
    hi PmenuMatchSel ctermfg=Black ctermbg=NONE cterm=bold
    hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuSel ctermfg=NONE ctermbg=Grey cterm=bold
    hi PmenuThumb ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi PreInsert ctermfg=Black ctermbg=NONE cterm=NONE
    hi PreProc ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi Question ctermfg=Blue ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=White ctermbg=Magenta cterm=bold
    hi Removed ctermfg=Red ctermbg=NONE cterm=NONE
    hi Repeat ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Search ctermfg=Black ctermbg=Cyan cterm=NONE
    hi SignColumn ctermfg=White ctermbg=NONE cterm=NONE
    hi Special ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=Red ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=Yellow ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=Blue ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=Green ctermbg=NONE cterm=underline
    hi Statement ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi StatusLine ctermfg=Black ctermbg=Grey cterm=bold,reverse
    hi StatusLineNC ctermfg=DarkGrey ctermbg=Grey cterm=NONE
    hi StorageClass ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi String ctermfg=Green ctermbg=NONE cterm=NONE
    hi Structure ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi TabLine ctermfg=DarkGrey ctermbg=Grey cterm=NONE
    hi TabLineFill ctermfg=NONE ctermbg=Grey cterm=NONE
    hi TabLineSel ctermfg=Black ctermbg=White cterm=NONE
    hi Tag ctermfg=DarkBlue ctermbg=NONE cterm=bold
    hi Title ctermfg=Blue ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=Black ctermbg=Grey cterm=NONE
    hi TitleBarNC ctermfg=DarkGrey ctermbg=Grey cterm=NONE
    hi Todo ctermfg=DarkRed ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=Red ctermbg=NONE cterm=NONE
    hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Type ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplit ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Visual ctermfg=Blue ctermbg=White cterm=bold,reverse
    hi VisualNOS ctermfg=NONE ctermbg=White cterm=bold
    hi WarningMsg ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi WildMenu ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi csvCol0 ctermfg=Red ctermbg=NONE cterm=NONE
    hi csvCol1 ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi csvCol2 ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi csvCol3 ctermfg=Green ctermbg=NONE cterm=NONE
    hi csvCol4 ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi csvCol5 ctermfg=Blue ctermbg=NONE cterm=NONE
    hi csvCol6 ctermfg=DarkBlue ctermbg=NONE cterm=NONE
    hi csvCol7 ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi csvCol8 ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi debugBreakpoint ctermfg=DarkGrey ctermbg=White cterm=NONE
    hi debugPC ctermfg=NONE ctermbg=Grey cterm=NONE
    hi diffAdded ctermfg=Green ctermbg=NONE cterm=NONE
    hi diffChanged ctermfg=Blue ctermbg=NONE cterm=NONE
    hi diffFile ctermfg=Blue ctermbg=NONE cterm=NONE
    hi diffIndexLine ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi diffLine ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi diffNewFile ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi diffOldFile ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi diffRemoved ctermfg=Red ctermbg=NONE cterm=NONE
    hi lCursor ctermfg=White ctermbg=Red cterm=NONE
    hi markdownCode ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi markdownCodeBlock ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi markdownH1 ctermfg=Red ctermbg=NONE cterm=NONE
    hi markdownH2 ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi markdownH3 ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi markdownH4 ctermfg=Green ctermbg=NONE cterm=NONE
    hi markdownH5 ctermfg=DarkCyan ctermbg=NONE cterm=NONE
    hi markdownH6 ctermfg=DarkBlue ctermbg=NONE cterm=NONE
    hi markdownHeadingDelimiter ctermfg=DarkYellow ctermbg=NONE cterm=bold
    hi markdownLinkText ctermfg=Blue ctermbg=NONE cterm=underline
    hi qfFileName ctermfg=Blue ctermbg=NONE cterm=NONE
    hi qfLineNr ctermfg=Yellow ctermbg=NONE cterm=NONE
    finish
  endif

  if s:t_Co >= 8
    hi Normal ctermfg=Black ctermbg=White cterm=NONE
    hi Added ctermfg=Green ctermbg=NONE cterm=NONE
    hi Bold ctermfg=NONE ctermbg=NONE cterm=bold
    hi Changed ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Character ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=White ctermbg=DarkGrey cterm=NONE
    hi Comment ctermfg=Black ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=Grey ctermbg=NONE cterm=NONE
    hi Conditional ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Constant ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi CurSearch ctermfg=Black ctermbg=Red cterm=NONE
    hi Cursor ctermfg=White ctermbg=Red cterm=NONE
    hi CursorColumn ctermfg=NONE ctermbg=Grey cterm=NONE
    hi CursorIM ctermfg=White ctermbg=DarkMagenta cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=Black ctermbg=NONE cterm=NONE
    hi Delimiter ctermfg=Black ctermbg=NONE cterm=NONE
    hi DiffAdd ctermfg=White ctermbg=Green cterm=NONE
    hi DiffChange ctermfg=White ctermbg=Yellow cterm=NONE
    hi DiffDelete ctermfg=White ctermbg=Red cterm=NONE
    hi DiffText ctermfg=White ctermbg=Cyan cterm=NONE
    hi Directory ctermfg=Blue ctermbg=NONE cterm=NONE
    hi EndOfBuffer ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Error ctermfg=Red ctermbg=NONE cterm=NONE
    hi ErrorMsg ctermfg=Red ctermbg=NONE cterm=bold
    hi Exception ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi FoldColumn ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Folded ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Function ctermfg=Blue ctermbg=NONE cterm=NONE
    hi Identifier ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi Include ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Italic ctermfg=NONE ctermbg=NONE cterm=italic
    hi Keyword ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Label ctermfg=DarkCyan ctermbg=NONE cterm=NONE
    hi LineNr ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Macro ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=DarkYellow ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=Black ctermbg=NONE cterm=bold
    hi MoreMsg ctermfg=Blue ctermbg=NONE cterm=NONE
    hi NonText ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Operator ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=Black ctermbg=Grey cterm=NONE
    hi PmenuExtra ctermfg=DarkGrey ctermbg=Grey cterm=NONE
    hi PmenuExtraSel ctermfg=DarkGrey ctermbg=Grey cterm=bold
    hi PmenuMatch ctermfg=Black ctermbg=NONE cterm=bold
    hi PmenuMatchSel ctermfg=Black ctermbg=NONE cterm=bold
    hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuSel ctermfg=NONE ctermbg=Grey cterm=bold
    hi PmenuThumb ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi PreInsert ctermfg=Black ctermbg=NONE cterm=NONE
    hi PreProc ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi Question ctermfg=Blue ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=Black ctermbg=Magenta cterm=bold
    hi Removed ctermfg=Red ctermbg=NONE cterm=NONE
    hi Repeat ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi Search ctermfg=Black ctermbg=Cyan cterm=NONE
    hi SignColumn ctermfg=White ctermbg=NONE cterm=NONE
    hi Special ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=Red ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=Yellow ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=Blue ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=Green ctermbg=NONE cterm=underline
    hi Statement ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi StatusLine ctermfg=Black ctermbg=Grey cterm=bold,reverse
    hi StatusLineNC ctermfg=DarkGrey ctermbg=Grey cterm=reverse
    hi StorageClass ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi String ctermfg=Green ctermbg=NONE cterm=NONE
    hi Structure ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi TabLine ctermfg=DarkGrey ctermbg=Grey cterm=NONE
    hi TabLineFill ctermfg=NONE ctermbg=Grey cterm=NONE
    hi TabLineSel ctermfg=Black ctermbg=Grey cterm=bold
    hi Tag ctermfg=DarkBlue ctermbg=NONE cterm=bold
    hi Title ctermfg=Blue ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=Black ctermbg=Grey cterm=NONE
    hi TitleBarNC ctermfg=DarkGrey ctermbg=Grey cterm=NONE
    hi Todo ctermfg=DarkRed ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=Red ctermbg=NONE cterm=NONE
    hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Type ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplit ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi Visual ctermfg=Blue ctermbg=White cterm=bold,reverse
    hi VisualNOS ctermfg=NONE ctermbg=White cterm=bold
    hi WarningMsg ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi WildMenu ctermfg=NONE ctermbg=DarkGrey cterm=NONE
    hi csvCol0 ctermfg=Red ctermbg=NONE cterm=NONE
    hi csvCol1 ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi csvCol2 ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi csvCol3 ctermfg=Green ctermbg=NONE cterm=NONE
    hi csvCol4 ctermfg=Cyan ctermbg=NONE cterm=NONE
    hi csvCol5 ctermfg=Blue ctermbg=NONE cterm=NONE
    hi csvCol6 ctermfg=DarkBlue ctermbg=NONE cterm=NONE
    hi csvCol7 ctermfg=DarkMagenta ctermbg=NONE cterm=NONE
    hi csvCol8 ctermfg=Magenta ctermbg=NONE cterm=NONE
    hi debugBreakpoint ctermfg=DarkGrey ctermbg=White cterm=NONE
    hi debugPC ctermfg=NONE ctermbg=Grey cterm=NONE
    hi diffAdded ctermfg=Green ctermbg=NONE cterm=NONE
    hi diffChanged ctermfg=Blue ctermbg=NONE cterm=NONE
    hi diffFile ctermfg=Blue ctermbg=NONE cterm=NONE
    hi diffIndexLine ctermfg=DarkGreen ctermbg=NONE cterm=NONE
    hi diffLine ctermfg=DarkGrey ctermbg=NONE cterm=NONE
    hi diffNewFile ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi diffOldFile ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi diffRemoved ctermfg=Red ctermbg=NONE cterm=NONE
    hi lCursor ctermfg=White ctermbg=Red cterm=NONE
    hi markdownCode ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi markdownCodeBlock ctermfg=DarkRed ctermbg=NONE cterm=NONE
    hi markdownH1 ctermfg=Red ctermbg=NONE cterm=NONE
    hi markdownH2 ctermfg=DarkYellow ctermbg=NONE cterm=NONE
    hi markdownH3 ctermfg=Yellow ctermbg=NONE cterm=NONE
    hi markdownH4 ctermfg=Green ctermbg=NONE cterm=NONE
    hi markdownH5 ctermfg=DarkCyan ctermbg=NONE cterm=NONE
    hi markdownH6 ctermfg=DarkBlue ctermbg=NONE cterm=NONE
    hi markdownHeadingDelimiter ctermfg=DarkYellow ctermbg=NONE cterm=bold
    hi markdownLinkText ctermfg=Blue ctermbg=NONE cterm=underline
    hi qfFileName ctermfg=Blue ctermbg=NONE cterm=NONE
    hi qfLineNr ctermfg=Yellow ctermbg=NONE cterm=NONE
    finish
  endif

  if s:t_Co >= 0
    hi CursorLineFold term=underline
    hi CursorLineSign term=underline
    hi Float term=NONE
    hi Ignore term=NONE
    hi IncSearch term=bold,reverse,underline
    hi Number term=NONE
    hi SpecialKey term=bold
    hi StatusLineTerm term=bold,reverse
    hi StatusLineTermNC term=bold,underline
    hi Terminal term=NONE
    finish
  endif

endif

" vim: et ts=8 sw=2 sts=2
