" Maintainer:   Oliver Corff <oliver.corff@email.de>
" Last Changed: 2018 Feb 12

scriptencoding utf-8

" oto = Old Turkic, Orkhon
let b:keymap_name = "oto"
highlight lCursor guibg=red guifg=NONE

" map F8 to toggle keymap (Ctrl-^ not present on keyboard)
noremap  <F8> :let &iminsert = ! &iminsert<CR>
lnoremap <F8> <C-^>
noremap! <F8> <C-^>

loadkeymap
A	𐰀	10C00	OLD TURKIC LETTER ORKHON A
00	𐰀	10C00	OLD TURKIC LETTER ORKHON A
I	𐰃	10C03	OLD TURKIC LETTER ORKHON I
03	𐰃	10C03	OLD TURKIC LETTER ORKHON I
O	𐰆	10C06	OLD TURKIC LETTER ORKHON O
U	𐰆	10C06	OLD TURKIC LETTER ORKHON O
06	𐰆	10C06	OLD TURKIC LETTER ORKHON O
OE	𐰇	10C07	OLD TURKIC LETTER ORKHON OE
UE	𐰇	10C07	OLD TURKIC LETTER ORKHON OE
07	𐰇	10C07	OLD TURKIC LETTER ORKHON OE
ab	𐰉	10C09	OLD TURKIC LETTER ORKHON AB
b1	𐰉	10C09	OLD TURKIC LETTER ORKHON AB
09	𐰉	10C09	OLD TURKIC LETTER ORKHON AB
aeb	𐰋	10C0B	OLD TURKIC LETTER ORKHON AEB
eb	𐰋	10C0B	OLD TURKIC LETTER ORKHON AEB
b2	𐰋	10C0B	OLD TURKIC LETTER ORKHON AEB
0b	𐰋	10C0B	OLD TURKIC LETTER ORKHON AEB
ag	𐰍	10C0D	OLD TURKIC LETTER ORKHON AG
g1	𐰍	10C0D	OLD TURKIC LETTER ORKHON AG
0d	𐰍	10C0D	OLD TURKIC LETTER ORKHON AG
aeg	𐰏	10C0F	OLD TURKIC LETTER ORKHON AEG
eg	𐰏	10C0F	OLD TURKIC LETTER ORKHON AEG
g2	𐰏	10C0F	OLD TURKIC LETTER ORKHON AEG
0f	𐰏	10C0F	OLD TURKIC LETTER ORKHON AEG
ad	𐰑	10C11	OLD TURKIC LETTER ORKHON AD
d1	𐰑	10C11	OLD TURKIC LETTER ORKHON AD
11	𐰑	10C11	OLD TURKIC LETTER ORKHON AD
aed	𐰓	10C13	OLD TURKIC LETTER ORKHON AED
ed	𐰓	10C13	OLD TURKIC LETTER ORKHON AED
d2	𐰓	10C13	OLD TURKIC LETTER ORKHON AED
13	𐰓	10C13	OLD TURKIC LETTER ORKHON AED
ez	𐰔	10C14	OLD TURKIC LETTER ORKHON EZ
z	𐰔	10C14	OLD TURKIC LETTER ORKHON EZ
14	𐰔	10C14	OLD TURKIC LETTER ORKHON EZ
ay	𐰖	10C16	OLD TURKIC LETTER ORKHON AY
y1	𐰖	10C16	OLD TURKIC LETTER ORKHON AY
16	𐰖	10C16	OLD TURKIC LETTER ORKHON AY
aey	𐰘	10C18	OLD TURKIC LETTER ORKHON AEY
ey	𐰘	10C18	OLD TURKIC LETTER ORKHON AEY
y2	𐰘	10C18	OLD TURKIC LETTER ORKHON AEY
18	𐰘	10C18	OLD TURKIC LETTER ORKHON AEY
aek	𐰚	10C1A	OLD TURKIC LETTER ORKHON AEK
k	𐰚	10C1A	OLD TURKIC LETTER ORKHON AEK
1a	𐰚	10C1A	OLD TURKIC LETTER ORKHON AEK
oek	𐰜	10C1C	OLD TURKIC LETTER ORKHON OEK
q	𐰜	10C1C	OLD TURKIC LETTER ORKHON OEK
1c	𐰜	10C1C	OLD TURKIC LETTER ORKHON OEK
al	𐰞	10C1E	OLD TURKIC LETTER ORKHON AL
l1	𐰞	10C1E	OLD TURKIC LETTER ORKHON AL
1e	𐰞	10C1E	OLD TURKIC LETTER ORKHON AL
ael	𐰠	10C20	OLD TURKIC LETTER ORKHON AEL
el	𐰠	10C20	OLD TURKIC LETTER ORKHON AEL
l2	𐰠	10C20	OLD TURKIC LETTER ORKHON AEL
20	𐰠	10C20	OLD TURKIC LETTER ORKHON AEL
elt	𐰡	10C21	OLD TURKIC LETTER ORKHON ELT
lt	𐰡	10C21	OLD TURKIC LETTER ORKHON ELT
21	𐰡	10C21	OLD TURKIC LETTER ORKHON ELT
em	𐰢	10C22	OLD TURKIC LETTER ORKHON EM
m	𐰢	10C22	OLD TURKIC LETTER ORKHON EM
22	𐰢	10C22	OLD TURKIC LETTER ORKHON EM
an	𐰣	10C23	OLD TURKIC LETTER ORKHON AN
n1	𐰣	10C23	OLD TURKIC LETTER ORKHON AN
23	𐰣	10C23	OLD TURKIC LETTER ORKHON AN
en	𐰤	10C24	OLD TURKIC LETTER ORKHON AEN
n2	𐰤	10C24	OLD TURKIC LETTER ORKHON AEN
24	𐰤	10C24	OLD TURKIC LETTER ORKHON AEN
ent	𐰦	10C26	OLD TURKIC LETTER ORKHON ENT
nt	𐰦	10C26	OLD TURKIC LETTER ORKHON ENT
26	𐰦	10C26	OLD TURKIC LETTER ORKHON ENT
enc	𐰨	10C28	OLD TURKIC LETTER ORKHON ENC
nc	𐰨	10C28	OLD TURKIC LETTER ORKHON ENC
28	𐰨	10C28	OLD TURKIC LETTER ORKHON ENC
eny	𐰪	10C2A	OLD TURKIC LETTER ORKHON ENY
ny	𐰪	10C2A	OLD TURKIC LETTER ORKHON ENY
2a	𐰪	10C2A	OLD TURKIC LETTER ORKHON ENY
eng	𐰭	10C2D	OLD TURKIC LETTER ORKHON ENG
ng	𐰭	10C2D	OLD TURKIC LETTER ORKHON ENG
2d	𐰭	10C2D	OLD TURKIC LETTER ORKHON ENG
ep	𐰯	10C2F	OLD TURKIC LETTER ORKHON EP
p	𐰯	10C2F	OLD TURKIC LETTER ORKHON EP
2f	𐰯	10C2F	OLD TURKIC LETTER ORKHON EP
op	𐰰	10C30	OLD TURKIC LETTER ORKHON OP
up	𐰰	10C30	OLD TURKIC LETTER ORKHON OP
30	𐰰	10C30	OLD TURKIC LETTER ORKHON OP
ic	𐰱	10C31	OLD TURKIC LETTER ORKHON IC
31	𐰱	10C31	OLD TURKIC LETTER ORKHON IC
ec	𐰲	10C32	OLD TURKIC LETTER ORKHON EC
32	𐰲	10C32	OLD TURKIC LETTER ORKHON EC
aq	𐰴	10C34	OLD TURKIC LETTER ORKHON AQ
34	𐰴	10C34	OLD TURKIC LETTER ORKHON AQ
iq	𐰶	10C36	OLD TURKIC LETTER ORKHON IQ
yq	𐰶	10C36	OLD TURKIC LETTER ORKHON IQ
36	𐰶	10C36	OLD TURKIC LETTER ORKHON IQ
oq	𐰸	10C38	OLD TURKIC LETTER ORKHON OQ
uq	𐰸	10C38	OLD TURKIC LETTER ORKHON OQ
38	𐰸	10C38	OLD TURKIC LETTER ORKHON OQ
ar	𐰺	10C3A	OLD TURKIC LETTER ORKHON AR
r1	𐰺	10C3A	OLD TURKIC LETTER ORKHON AR
3a	𐰺	10C3A	OLD TURKIC LETTER ORKHON AR
aer	𐰼	10C3C	OLD TURKIC LETTER ORKHON AER
er	𐰼	10C3C	OLD TURKIC LETTER ORKHON AER
r2	𐰼	10C3C	OLD TURKIC LETTER ORKHON AER
3c	𐰼	10C3C	OLD TURKIC LETTER ORKHON AER
as	𐰽	10C3D	OLD TURKIC LETTER ORKHON AS
s1	𐰽	10C3D	OLD TURKIC LETTER ORKHON AS
3d	𐰽	10C3D	OLD TURKIC LETTER ORKHON AS
aes	𐰾	10C3E	OLD TURKIC LETTER ORKHON AES
es	𐰾	10C3E	OLD TURKIC LETTER ORKHON AES
s2	𐰾	10C3E	OLD TURKIC LETTER ORKHON AES
3e	𐰾	10C3E	OLD TURKIC LETTER ORKHON AES
ash	𐰿	10C3F	OLD TURKIC LETTER ORKHON ASH
sh1	𐰿	10C3F	OLD TURKIC LETTER ORKHON ASH
3f	𐰿	10C3F	OLD TURKIC LETTER ORKHON ASH
esh	𐱁	10C41	OLD TURKIC LETTER ORKHON ESH
sh2	𐱁	10C41	OLD TURKIC LETTER ORKHON ESH
41	𐱁	10C41	OLD TURKIC LETTER ORKHON ESH
at	𐱃	10C43	OLD TURKIC LETTER ORKHON AT
t1	𐱃	10C43	OLD TURKIC LETTER ORKHON AT
43	𐱃	10C43	OLD TURKIC LETTER ORKHON AT
aet	𐱅	10C45	OLD TURKIC LETTER ORKHON AET
et	𐱅	10C45	OLD TURKIC LETTER ORKHON AET
t2	𐱅	10C45	OLD TURKIC LETTER ORKHON AET
45	𐱅	10C45	OLD TURKIC LETTER ORKHON AET
ot	𐱇	10C47	OLD TURKIC LETTER ORKHON OT
ut	𐱇	10C47	OLD TURKIC LETTER ORKHON OT
47	𐱇	10C47	OLD TURKIC LETTER ORKHON OT
bash	𐱈	10C48	OLD TURKIC LETTER ORKHON BASH
48	𐱈	10C48	OLD TURKIC LETTER ORKHON BASH
